# NMDC SCHEMA
~~Do not add files to this directory~~
~~This directory is used for building the PyPI package. Files are added during the package build process.~~

`nmdc.py` is autogenerated by `make site` etc.

Other Python scripts to be included in the PyPI package should be placed here.

Many of these scripts were written by Bill Duncan, but the history may have been lost during various repo reorgs.
